<?php

declare(strict_types=1);

namespace Plugin\cin_bistro_5\Portlets\OpeningHoursTitle;

require_once \dirname(__DIR__, 2).'/src/BistroService.php';

use Cin\Bistro5\BistroService;
use Cin\Bistro5\PortletTrait;
use JTL\OPC\InputType;
use JTL\OPC\Portlet;
use JTL\OPC\PortletInstance;

final class OpeningHoursTitle extends Portlet
{
  use PortletTrait;

  public function getButtonHtml(): string
  {
    return $this->getFontAwesomeButtonHtml('fas fa-font');
  }

  public function getPropertyDesc(): array
  {
    return [
      'opened-var-hint' => [
        'label' => 'note',
        'type'  => InputType::HINT,
        'class' => 'info',
        'text'  => __('opened-var-note'),
      ],
      'opened' => [
        'label'   => __('po_text_styling'),
        'type'    => InputType::RICHTEXT,
        'default' => $this->__t('open_until', __('open_until')).' $day $close',
      ],
      'reopen-var-hint' => [
        'label' => 'note',
        'type'  => InputType::HINT,
        'class' => 'info',
        'text'  => __('reopen-var-note'),
      ],
      'reopen' => [
        'label'   => __('po_text_styling'),
        'type'    => InputType::RICHTEXT,
        'default' => $this->__t('open_at', __('open_at')).' $day $open',
      ],
      'closing-var-hint' => [
        'label' => 'note',
        'type'  => InputType::HINT,
        'class' => 'info',
        'text'  => __('closing-var-note'),
      ],
      'closing' => [
        'label'   => __('po_text_styling'),
        'type'    => InputType::RICHTEXT,
        'default' => sprintf($this->__t('close_event', __('close_event')), '$event', '$from', '$to'),
      ],
    ];
  }

  public function getPropertyTabs(): array
  {
    return [
      __('po_open_to') => [
        'opened-var-hint',
        'opened',
      ],
      __('po_reopen_at') => [
        'reopen-var-hint',
        'reopen',
      ],
      __('po_closing_hour') => [
        'closing-var-hint',
        'closing',
      ],
      __('Styles')    => 'styles',
      __('Animation') => 'animations',
    ];
  }

  /**
   * $this->__t('cin_week_mon', __('cin_week_mon'))
   * $this->__t('cin_week_tue', __('cin_week_tue'))
   * $this->__t('cin_week_wed', __('cin_week_wed'))
   * $this->__t('cin_week_thu', __('cin_week_thu'))
   * $this->__t('cin_week_fri', __('cin_week_fri'))
   * $this->__t('cin_week_sat', __('cin_week_sat'))
   * $this->__t('cin_week_sun', __('cin_week_sun')).
   */
  public function loader(PortletInstance $instance): string
  {
    if (BistroService::IsDayInClosingHours()) {
      // TODO show closing hours information
      $closings = BistroService::GetClosings();

      $text = str_replace('$event', $closings['reason'], $instance->getProperty('closing'));
      $text = str_replace('$from', date('d.m.Y', strtotime($closings['from'])), $text);

      return str_replace('$to', date('d.m.Y', strtotime($closings['to'])), $text);
    }

    if (/*BistroService::IsGenerallyOpened()*/ BistroService::IsOpened()) {
      $closing = BistroService::NextClosing();

      $text = str_replace('$close', mb_substr($closing['closeAt'], 0, 5), $instance->getProperty('opened'));
      $text = str_replace('$day', __('cin_week_'.$closing['onDay']), $text);

      return str_replace('$nth', (string) $closing['nth'], $text);
    }

    if (empty($reopen = BistroService::NextOpening())) {
      return '';
    }

    $text = str_replace('$open', mb_substr($reopen['openAt'], 0, 5), $instance->getProperty('reopen'));
    $text = str_replace('$day', __('cin_week_'.$reopen['onDay']), $text);

    return str_replace('$nth', (string) $reopen['nth'], $text);
  }
}
